# [A]DVENTURE! [V]ILLAINY! [E]XCITEMENT!

AVE: Adventure! Villainy! Excitement! is a text-based game engine
written by Matthew Scroggs.

AVE can currently run on Linux or Mac.

To run AVE, run `./run.py` in terminal. To run AVE in debug mode, run `DEBUG=1 ./run.py` or `DEBUG=1 python run.py`.

To make your own game for AVE, see `games/INSTRUCTIONS.md`.

### Collaborators
- [mscroggs](http://github.com/mscroggs) - Lead programmer and story writing
- [Giannie](http://github.com/Giannie) - Programming and story writing
- [boltiboi](http://github.com/boltiboi) - Came up with the name AVE and story writing
- [aaclarke4](http://github.com/aaclarke4) - Story writing

[avegame.co.uk](http://avegame.co.uk)

[github.com/AVEgame/AVE](http://github.com/AVEgame/AVE)

The repository for the AVE website is at [github.com/AVEgame/AVE-website](http://github.com/AVEgame/AVE-website).
